ThreeDViewer class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ThreeDViewer
Constructors
-
ThreeDViewer({Key? key, required String assetPath, Color backgroundColor = const Color(0xFFF0F0F0), ThreeDZoomConfig zoomConfig = const ThreeDZoomConfig(), ThreeDAutoRotateConfig autoRotateConfig = const ThreeDAutoRotateConfig(), ThreeDDebugConfig debugConfig = const ThreeDDebugConfig(), ThreeDEnvironmentConfig? environmentConfig, List<
ThreeDHotspot> ? hotspots, List<ThreeDOverlay> ? overlays, bool enableRotate = true, bool enablePan = true, bool enableBoundaries = true, bool autoCenter = false, bool showHotspots = false, bool enableDoubleTapZoom = false, ThreeDRotationLimits? rotationLimits, List<double> ? initialCameraPosition, List<double> ? initialTargetPosition, bool autoPlay = true, ThreeDViewerController? controller, dynamic onAnimationsLoaded(List<ThreeDAnimation> animations)?, dynamic onHotspotTapped(String id)?, dynamic onObjectDoubleTapped(String id)?, Widget? customLoader}) -
const
Properties
- assetPath → String
-
final
- autoCenter → bool
-
final
- autoPlay → bool
-
final
- autoRotateConfig → ThreeDAutoRotateConfig
-
final
- backgroundColor → Color
-
final
- controller → ThreeDViewerController?
-
final
- customLoader → Widget?
-
final
- debugConfig → ThreeDDebugConfig
-
final
- enableBoundaries → bool
-
final
- enableDoubleTapZoom → bool
-
final
- enablePan → bool
-
final
- enableRotate → bool
-
final
- environmentConfig → ThreeDEnvironmentConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hotspots
→ List<
ThreeDHotspot> ? -
final
-
initialCameraPosition
→ List<
double> ? -
final
-
initialTargetPosition
→ List<
double> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onAnimationsLoaded
→ dynamic Function(List<
ThreeDAnimation> animations)? -
final
- onHotspotTapped → dynamic Function(String id)?
-
final
- onObjectDoubleTapped → dynamic Function(String id)?
-
final
-
overlays
→ List<
ThreeDOverlay> ? -
final
- rotationLimits → ThreeDRotationLimits?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHotspots → bool
-
final
- zoomConfig → ThreeDZoomConfig
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ThreeDViewer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited